==> nextcloud-22.2.10.tgz: nextcloud/apps/theming/l10n/es_DO.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando vista previa...",
    "Admin" : "Administración",
    "Saved" : "Guardado",
    "a safe home for all your data" : "un lugar seguro para todos tus datos",
    "Name cannot be empty" : "El nombre no puede estar en blanco",
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given legal notice address is too long" : "La dirección del aviso legal es demasiado larga",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "No file uploaded" : "No hay archivos cargados",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya te encuentras usando un tema personalizado. La aplicación de Temas puede estar siendo sobreescrita por él.",
    "Theming" : "Tematizar",
    "Dark theme" : "Tema Oscuro",
    "Enable dark theme" : "Habilita el tema oscuro",
    "Dyslexia font" : "Fuente para las personas con dislexia",
    "Enable dyslexia font" : "Habilita la fuente de dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra o fuente gratuito diseñado para mitigar algunos de los errores de lectura comunes causados ​​por la dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Habilita el modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para mejorar tu navegacion. La calidad visual se vera reducida pero la claridad se mejorara.",
    "Legal notice" : "Aviso legal",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo se pueda usar también sin mouse y software de asistencia, como lectores de pantalla. Nuestro objetivo es cumplir con las {guidelines}Pautas de accesibilidad al contenido web{linkend} 2.1 en el nivel AA, con el tema de alto contraste incluso en el nivel AAA.",
    "Open documentation" : "Abrir la documentación",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Name" : "Nombre",
    "Reset to default" : "Restablecer al predeterminado",
    "Web link" : "Enlace web",
    "https://…" : "https://…",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotipo",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Login image" : "Imágen de inicio de sesión",
    "Upload new login background" : "Cargar nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "Advanced options" : "Opciones avanzadas",
    "Legal notice link" : "Enlace al aviso legal",
    "Header logo" : "Logo del encabezado",
    "Upload new header logo" : "Cargar un nuevo logotipo del encabezado",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Cargar un nuevo favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión Imagemagick de PHP con soporte a imagenes SVG para generar los favicons en automático con base en el logotipo cargado y el color."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-23.0.5.tgz: nextcloud/apps/theming/l10n/es_DO.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando vista previa...",
    "Admin" : "Administración",
    "Saved" : "Guardado",
    "a safe home for all your data" : "un lugar seguro para todos tus datos",
    "Name cannot be empty" : "El nombre no puede estar en blanco",
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given legal notice address is too long" : "La dirección del aviso legal es demasiado larga",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "No file uploaded" : "No hay archivos cargados",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya te encuentras usando un tema personalizado. La aplicación de Temas puede estar siendo sobreescrita por él.",
    "Theming" : "Tematizar",
    "Dark theme" : "Tema Oscuro",
    "Enable dark theme" : "Habilita el tema oscuro",
    "Dyslexia font" : "Fuente para las personas con dislexia",
    "Enable dyslexia font" : "Habilita la fuente de dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra o fuente gratuito diseñado para mitigar algunos de los errores de lectura comunes causados ​​por la dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Habilita el modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para mejorar tu navegacion. La calidad visual se vera reducida pero la claridad se mejorara.",
    "Legal notice" : "Aviso legal",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo se pueda usar también sin mouse y software de asistencia, como lectores de pantalla. Nuestro objetivo es cumplir con las {guidelines}Pautas de accesibilidad al contenido web{linkend} 2.1 en el nivel AA, con el tema de alto contraste incluso en el nivel AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentras cualquier problemas, no dudes de reportarlos en {issuetracker}nuestro rastreador de problemas{linkend}. Y si quieres participar, únete a {designteam}nuestro equipo de diseño{linkend}.",
    "Open documentation" : "Abrir la documentación",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Name" : "Nombre",
    "Reset to default" : "Restablecer al predeterminado",
    "Web link" : "Enlace web",
    "https://…" : "https://…",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotipo",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Login image" : "Imágen de inicio de sesión",
    "Upload new login background" : "Cargar nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "Advanced options" : "Opciones avanzadas",
    "Legal notice link" : "Enlace al aviso legal",
    "Header logo" : "Logo del encabezado",
    "Upload new header logo" : "Cargar un nuevo logotipo del encabezado",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Cargar un nuevo favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión Imagemagick de PHP con soporte a imagenes SVG para generar los favicons en automático con base en el logotipo cargado y el color."
},
"nplurals=2; plural=(n != 1);");
